@@ -7,6 +7,8 @@
  *	Michael Meeks    (michael@helixcode.com)
  *	Ettore Perazzoli (ettore@helixcode.com)
  */
+/* #include <syslog.h> */
+
 #include <bonobo/bonobo-moniker-util.h>
 #include <bonobo/bonobo-exception.h>
 #include <liboaf/liboaf.h>
@@ -404,8 +406,11 @@ bonobo_moniker_util_unescape (const char *string, int num_chars)
 	for (i = 0; i < num_chars; i++) {
 		if (string [i] == '\0')
 			break;
-		else if (string [i] == '\\')
+		else if (string [i] == '\\') {
+			if (string [i + 1] == '\\')
+				i++;
 			backslashes ++;
+		}
 	}
 
 	if (!backslashes)
@@ -563,21 +568,27 @@ bonobo_get_object (const CORBA_char *name,
 		   CORBA_Environment *ev)
 {
 	Bonobo_Moniker moniker;
-	Bonobo_Unknown retval;
+	Bonobo_Unknown retval = CORBA_OBJECT_NIL;
 
 	moniker = bonobo_moniker_client_new_from_name (name, ev);
 
-	if (BONOBO_EX (ev))
-		return CORBA_OBJECT_NIL;
+	if (BONOBO_EX (ev)) 
+		retval = CORBA_OBJECT_NIL;
+	else {
+		retval = bonobo_moniker_client_resolve_default (
+			moniker, interface_name, ev);
 
-	retval = bonobo_moniker_client_resolve_default (
-		moniker, interface_name, ev);
+		bonobo_object_release_unref (moniker, ev);
+		
+		if (BONOBO_EX (ev))
+			retval = CORBA_OBJECT_NIL;
+	}
 
-	bonobo_object_release_unref (moniker, ev);
+/*	syslog (LOG_WARNING, "Bonobo: get_object '%s' '%s' returns %p ex '%s'",
+		name ? name : "<null>", interface_name ? interface_name : "<null>",
+		retval, ev->_major == CORBA_NO_EXCEPTION ? "<no exception>" : 
+		bonobo_exception_get_text (ev)); */
 
-	if (BONOBO_EX (ev))
-		return CORBA_OBJECT_NIL;
-	
 	return retval;
 }
 
