@@ -718,7 +718,9 @@ bonobo_property_bag_xml_decode_any (BonoboUINode      *node,
 			(ORBit_free_childvals) ORBit_free_via_TypeCode,
 			GINT_TO_POINTER (1), sizeof(CORBA_TypeCode));
 		*(CORBA_TypeCode *)((char *) retval - sizeof (ORBit_mem_info) -
-				    sizeof (CORBA_TypeCode)) = tc;
+				    sizeof (CORBA_TypeCode)) = 
+			(CORBA_TypeCode) CORBA_Object_duplicate (
+				(CORBA_Object) tc, ev);
 	} else
 		retval = NULL;
 
